<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="29"/>
        <source>Row</source>
        <translation>行</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="30"/>
        <source>Column</source>
        <translation>列</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="31"/>
        <source>Characters %1</source>
        <translation>字数 %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="42"/>
        <source>Loading:</source>
        <translation>文件加载中：</translation>
    </message>
</context>
<context>
    <name>DDropdownMenu</name>
    <message>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="298"/>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="349"/>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="354"/>
        <source>None</source>
        <translation>无</translation>
    </message>
</context>
<context>
    <name>EditWrapper</name>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="309"/>
        <location filename="../src/editor/editwrapper.cpp" line="375"/>
        <location filename="../src/editor/editwrapper.cpp" line="505"/>
        <location filename="../src/editor/editwrapper.cpp" line="789"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="500"/>
        <source>Do you want to save this file?</source>
        <translation>您是否要保存此文件？</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="373"/>
        <location filename="../src/editor/editwrapper.cpp" line="503"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="370"/>
        <source>Encoding changed. Do you want to save the file now?</source>
        <translation>文件编码已更改，是否先进行保存？</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="504"/>
        <source>Discard</source>
        <translation>不保存</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="238"/>
        <location filename="../src/editor/editwrapper.cpp" line="647"/>
        <source>You do not have permission to save %1</source>
        <translation>您没有权限保存%1</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="866"/>
        <source>File removed on the disk. Save it now?</source>
        <translation>磁盘中的原文件已被移除，是否另存？</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="871"/>
        <source>File has changed on disk. Reload?</source>
        <translation>磁盘中的原文件已被修改，是否重新载入？</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="901"/>
        <location filename="../src/widgets/bottombar.cpp" line="72"/>
        <source>INSERT</source>
        <translation>插入</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="904"/>
        <source>OVERWRITE</source>
        <translation>覆盖</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="907"/>
        <source>R/O</source>
        <translation>只读</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="1050"/>
        <source>The file cannot be read, which may be too large or has been damaged!</source>
        <translation>无法读取该文件，文件可能过大或损坏</translation>
    </message>
</context>
<context>
    <name>FindBar</name>
    <message>
        <location filename="../src/controls/findbar.cpp" line="32"/>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <location filename="../src/controls/findbar.cpp" line="34"/>
        <source>Previous</source>
        <translation>上一个</translation>
    </message>
    <message>
        <location filename="../src/controls/findbar.cpp" line="35"/>
        <source>Next</source>
        <translation>下一个</translation>
    </message>
</context>
<context>
    <name>JumpLineBar</name>
    <message>
        <location filename="../src/controls/jumplinebar.cpp" line="44"/>
        <source>Go to Line: </source>
        <translation>跳到行：</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/editorapplication.cpp" line="11"/>
        <source>Text Editor is a powerful tool for viewing and editing text files.</source>
        <translation>文本编辑器是一款用来查看和编辑文本文件的工具。</translation>
    </message>
    <message>
        <location filename="../src/editorapplication.cpp" line="22"/>
        <source>Text Editor</source>
        <translation>文本编辑器</translation>
    </message>
</context>
<context>
    <name>PathSettingWgt</name>
    <message>
        <location filename="../src/widgets/pathsettintwgt.cpp" line="76"/>
        <source>Remember the last used path</source>
        <translation>记住最后的操作路径</translation>
    </message>
    <message>
        <location filename="../src/widgets/pathsettintwgt.cpp" line="77"/>
        <source>Same path as the current file</source>
        <translation>与当前文件保持一致</translation>
    </message>
    <message>
        <location filename="../src/widgets/pathsettintwgt.cpp" line="78"/>
        <source>Customize the default path</source>
        <translation>自定义操作路径</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/editorapplication.cpp" line="19"/>
        <source>Text Editor</source>
        <translation>文本编辑器</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="311"/>
        <location filename="../src/editor/editwrapper.cpp" line="799"/>
        <location filename="../src/editor/editwrapper.cpp" line="812"/>
        <location filename="../src/widgets/window.cpp" line="1170"/>
        <location filename="../src/widgets/window.cpp" line="1193"/>
        <location filename="../src/widgets/window.cpp" line="1304"/>
        <location filename="../src/widgets/window.cpp" line="1319"/>
        <source>Encoding</source>
        <translation>编码</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="9"/>
        <source>Basic</source>
        <translation>基础设置</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="10"/>
        <source>Font Style</source>
        <translation>字体样式</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="11"/>
        <source>Font</source>
        <translation>字体</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="12"/>
        <source>Font Size</source>
        <translation>字号</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="13"/>
        <source>Shortcuts</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="14"/>
        <location filename="../src/controls/settingsdialog.cpp" line="15"/>
        <source>Keymap</source>
        <translation>快捷键映射</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="16"/>
        <location filename="../src/controls/settingsdialog.cpp" line="94"/>
        <location filename="../src/widgets/window.cpp" line="2039"/>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="17"/>
        <source>New tab</source>
        <translation>新标签页</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="18"/>
        <source>New window</source>
        <translation>新窗口</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="19"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="20"/>
        <source>Save as</source>
        <translation>另存为</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="21"/>
        <source>Next tab</source>
        <translation>下一个标签页</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="22"/>
        <source>Previous tab</source>
        <translation>上一个标签页</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="23"/>
        <source>Close tab</source>
        <translation>关闭标签页</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="24"/>
        <source>Close other tabs</source>
        <translation>关闭其他标签页</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="25"/>
        <source>Restore tab</source>
        <translation>恢复标签页</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="26"/>
        <source>Open file</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="27"/>
        <source>Increment font size</source>
        <translation>放大字号</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="28"/>
        <source>Decrement font size</source>
        <translation>缩小字号</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="29"/>
        <source>Reset font size</source>
        <translation>还原字号</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="30"/>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="31"/>
        <source>Toggle fullscreen</source>
        <translation>切换全屏</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="32"/>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="33"/>
        <source>Find Next</source>
        <translation>查找下一个</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="34"/>
        <source>Find Previous</source>
        <translation>查找上一个</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="35"/>
        <source>Replace</source>
        <translation>替换</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="36"/>
        <source>Go to line</source>
        <translation>跳到行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="37"/>
        <source>Save cursor position</source>
        <translation>保存光标位置</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="38"/>
        <source>Reset cursor position</source>
        <translation>跳转到保存光标位置</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="39"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="40"/>
        <source>Display shortcuts</source>
        <translation>显示快捷键</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="41"/>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="42"/>
        <source>Editor</source>
        <translation>编辑</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="43"/>
        <source>Increase indent</source>
        <translation>增加缩进</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="44"/>
        <source>Decrease indent</source>
        <translation>减少缩进</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="45"/>
        <source>Forward character</source>
        <translation>右移一个字符</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="46"/>
        <source>Backward character</source>
        <translation>左移一个字符</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="47"/>
        <source>Forward word</source>
        <translation>右移一个词</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="48"/>
        <source>Backward word</source>
        <translation>左移一个词</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="49"/>
        <source>Next line</source>
        <translation>下一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="50"/>
        <source>Previous line</source>
        <translation>上一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="51"/>
        <source>New line</source>
        <translation>换行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="52"/>
        <source>New line above</source>
        <translation>向上插入一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="53"/>
        <source>New line below</source>
        <translation>向下插入一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="54"/>
        <source>Duplicate line</source>
        <translation>复制并粘贴当前行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="55"/>
        <source>Delete to end of line</source>
        <translation>删除到行尾</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="56"/>
        <source>Delete current line</source>
        <translation>删除当前行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="57"/>
        <source>Swap line up</source>
        <translation>上移一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="58"/>
        <source>Swap line down</source>
        <translation>下移一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="59"/>
        <source>Scroll up one line</source>
        <translation>向上滚动一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="60"/>
        <source>Scroll down one line</source>
        <translation>向下滚动一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="61"/>
        <source>Page up</source>
        <translation>向上滚动一页</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="62"/>
        <source>Page down</source>
        <translation>向下滚动一页</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="63"/>
        <source>Move to end of line</source>
        <translation>移动到行尾</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="64"/>
        <source>Move to start of line</source>
        <translation>移动到行头</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="65"/>
        <source>Move to end of text</source>
        <translation>移动到文本结尾</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="66"/>
        <source>Move to start of text</source>
        <translation>移动到文本开头</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="67"/>
        <source>Move to line indentation</source>
        <translation>移动到行缩进</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="68"/>
        <source>Upper case</source>
        <translation>转换为大写</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="69"/>
        <source>Lower case</source>
        <translation>转换为小写</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="70"/>
        <source>Capitalize</source>
        <translation>首字母大写</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="71"/>
        <source>Delete backward word</source>
        <translation>向左删除一个词</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="72"/>
        <source>Delete forward word</source>
        <translation>向右删除一个词</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="73"/>
        <source>Forward over a pair</source>
        <translation>向右匹配</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="74"/>
        <source>Backward over a pair</source>
        <translation>向左匹配</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="75"/>
        <source>Select all</source>
        <translation>全选</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="76"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="77"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="78"/>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="79"/>
        <source>Transpose character</source>
        <translation>调换字符</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="80"/>
        <source>Mark</source>
        <translation>设置标记</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="81"/>
        <source>Unmark</source>
        <translation>取消标记</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="82"/>
        <source>Copy line</source>
        <translation>复制行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="83"/>
        <source>Cut line</source>
        <translation>剪切行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="84"/>
        <source>Merge lines</source>
        <translation>合并行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="85"/>
        <source>Read-Only mode</source>
        <translation>切换到只读模式</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="86"/>
        <source>Add comment</source>
        <translation>添加注释</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="87"/>
        <source>Remove comment</source>
        <translation>取消注释</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="88"/>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="89"/>
        <source>Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="90"/>
        <source>Add/Remove bookmark</source>
        <translation>添加/清除书签</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="91"/>
        <source>Move to previous bookmark</source>
        <translation>跳转到上一个书签</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="92"/>
        <source>Move to next bookmark</source>
        <translation>跳转到下一个书签</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="93"/>
        <source>Advanced</source>
        <translation>高级设置</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="95"/>
        <source>Window size</source>
        <translation>窗口状态</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="96"/>
        <source>Tab width</source>
        <translation>Tab字符宽度</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="97"/>
        <source>Paste by pressing a middle mouse button</source>
        <translation>允许鼠标中键粘贴</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="99"/>
        <source>Startup</source>
        <translation>启动</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="100"/>
        <source>Reopen last closed tabs</source>
        <translation>保留关闭前的页签</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="102"/>
        <source>Open/Save Settings</source>
        <translation>打开/保存设置</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="104"/>
        <source>Word wrap</source>
        <translation>自动换行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="105"/>
        <source>Code folding flag</source>
        <translation>显示代码折叠标志</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="106"/>
        <source>Show line numbers</source>
        <translation>显示行号</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="107"/>
        <source>Show bookmarks icon</source>
        <translation>显示书签图标</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="108"/>
        <source>Show whitespaces and tabs</source>
        <translation>显示空白字符/制表符</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="109"/>
        <source>Highlight current line</source>
        <translation>当前行高亮</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="110"/>
        <source>Color mark</source>
        <translation>颜色标记</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="113"/>
        <source>Unicode</source>
        <translation>Unicode</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="114"/>
        <source>WesternEuropean</source>
        <translation>西欧语系</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="115"/>
        <source>CentralEuropean</source>
        <translation>中欧语系</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="116"/>
        <source>Baltic</source>
        <translation>波罗的海语言</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="117"/>
        <source>Cyrillic</source>
        <translation>西里尔文</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="118"/>
        <source>Arabic</source>
        <translation>阿拉伯语</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="123"/>
        <source>Celtic</source>
        <translation>凯尔特语</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="124"/>
        <source>SouthEasternEuropean</source>
        <translation>东南欧语系</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="119"/>
        <source>Greek</source>
        <translation>希腊语</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="120"/>
        <source>Hebrew</source>
        <translation>希伯来语</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="125"/>
        <source>ChineseSimplified</source>
        <translation>简体中文</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="126"/>
        <source>ChineseTraditional</source>
        <translation>繁体中文</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="127"/>
        <source>Japanese</source>
        <translation>日语</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="128"/>
        <source>Korean</source>
        <translation>韩语</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="122"/>
        <source>Thai</source>
        <translation>泰语</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="121"/>
        <source>Turkish</source>
        <translation>土耳其语</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="129"/>
        <source>Vietnamese</source>
        <translation>越南语</translation>
    </message>
    <message>
        <location filename="../src/startmanager.cpp" line="838"/>
        <source>File not saved</source>
        <translation>文件未保存</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1305"/>
        <location filename="../src/widgets/window.cpp" line="1320"/>
        <source>Line Endings</source>
        <translation>换行符</translation>
    </message>
    <message>
        <location filename="../src/common/iflytek_ai_assistant.cpp" line="168"/>
        <source>Please install &apos;UOS AI&apos; from the App Store before using</source>
        <translation>请前往应用商店安装“UOS AI”后再使用</translation>
    </message>
    <message>
        <location filename="../src/common/iflytek_ai_assistant.cpp" line="170"/>
        <source>No audio input device detected. Please check and try again</source>
        <translation>未检测到音频输入设备，请检查后重试</translation>
    </message>
    <message>
        <location filename="../src/common/iflytek_ai_assistant.cpp" line="172"/>
        <source>No audio output device detected. Please check and try again</source>
        <translation>未检测到音频输出设备，请检查后重试</translation>
    </message>
</context>
<context>
    <name>ReplaceBar</name>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="31"/>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="33"/>
        <source>Replace With</source>
        <translation>替换为</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="35"/>
        <source>Replace</source>
        <translation>替换</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="36"/>
        <source>Skip</source>
        <translation>跳过</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="37"/>
        <source>Replace Rest</source>
        <translation>剩余替换</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="38"/>
        <source>Replace All</source>
        <translation>全部替换</translation>
    </message>
</context>
<context>
    <name>S:</name>
    <message>
        <location filename="../third/libiconv-1.16/src/iconv.c" line="103"/>
        <source></source>
        <comment>The first line of the short usage message.</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/common/settings.cpp" line="117"/>
        <source>Standard</source>
        <translation>标准</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="117"/>
        <source>Customize</source>
        <translation>自定义</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="130"/>
        <source>Normal</source>
        <translation>正常窗口</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="130"/>
        <source>Maximum</source>
        <translation>最大化</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="130"/>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="412"/>
        <source>This shortcut conflicts with system shortcut %1</source>
        <translation>此快捷键与系统快捷键%1冲突</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="414"/>
        <source>This shortcut conflicts with %1, click on Replace to make this shortcut effective immediately</source>
        <translation>此快捷键与%1冲突，点击替换使这个快捷键立即生效</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="570"/>
        <location filename="../src/common/settings.cpp" line="578"/>
        <location filename="../src/common/settings.cpp" line="586"/>
        <source>The shortcut %1 is invalid, please set another one.</source>
        <translation>%1为无效快捷键，请重新设置</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="613"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="614"/>
        <source>Replace</source>
        <translation>替换</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="616"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>StartManager</name>
    <message>
        <location filename="../src/startmanager.cpp" line="355"/>
        <source>Untitled %1</source>
        <translation>未命名文档%1</translation>
    </message>
</context>
<context>
    <name>Tabbar</name>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="552"/>
        <source>Close tab</source>
        <translation>关闭标签页</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="553"/>
        <source>Close other tabs</source>
        <translation>关闭其他标签页</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="554"/>
        <source>More options</source>
        <translation>更多关闭方式</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="555"/>
        <source>Close tabs to the left</source>
        <translation>关闭左侧所有标签页</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="556"/>
        <source>Close tabs to the right</source>
        <translation>关闭右侧所有标签页</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="557"/>
        <source>Close unmodified tabs</source>
        <translation>关闭所有未修改标签页</translation>
    </message>
</context>
<context>
    <name>TextEdit</name>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="270"/>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="271"/>
        <source>Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="272"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="273"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="274"/>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="275"/>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="276"/>
        <source>Select All</source>
        <translation>全选</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="277"/>
        <location filename="../src/widgets/window.cpp" line="488"/>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="278"/>
        <location filename="../src/widgets/window.cpp" line="489"/>
        <source>Replace</source>
        <translation>替换</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="279"/>
        <source>Go to Line</source>
        <translation>跳到行</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="280"/>
        <source>Turn on Read-Only mode</source>
        <translation>开启只读模式</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="281"/>
        <source>Turn off Read-Only mode</source>
        <translation>关闭只读模式</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="282"/>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="283"/>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="284"/>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="285"/>
        <location filename="../src/editor/dtextedit.cpp" line="337"/>
        <source>Add Comment</source>
        <translation>添加注释</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="286"/>
        <source>Text to Speech</source>
        <translation>语音朗读</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="287"/>
        <source>Stop reading</source>
        <translation>停止朗读</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="288"/>
        <source>Speech to Text</source>
        <translation>语音听写</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="289"/>
        <source>Translate</source>
        <translation>文本翻译</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="290"/>
        <source>Column Mode</source>
        <translation>列编辑模式</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="291"/>
        <source>Add bookmark</source>
        <translation>添加书签</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="292"/>
        <source>Remove Bookmark</source>
        <translation>清除书签</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="293"/>
        <source>Previous bookmark</source>
        <translation>上一个书签</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="294"/>
        <source>Next bookmark</source>
        <translation>下一个书签</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="295"/>
        <source>Remove All Bookmarks</source>
        <translation>清除所有书签</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="296"/>
        <source>Fold All</source>
        <translation>折叠所有层次</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="297"/>
        <source>Fold Current Level</source>
        <translation>折叠当前层次</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="298"/>
        <source>Unfold All</source>
        <translation>展开所有层次</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="299"/>
        <source>Unfold Current Level</source>
        <translation>展开当前层次</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="304"/>
        <source>Color Mark</source>
        <translation>颜色标记</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="308"/>
        <source>Clear All Marks</source>
        <translation>清除所有标记</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="309"/>
        <source>Clear Last Mark</source>
        <translation>清除上次标记</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="318"/>
        <source>Mark</source>
        <translation>添加标记</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="330"/>
        <source>Mark All</source>
        <translation>标记所有</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="338"/>
        <source>Remove Comment</source>
        <translation>取消注释</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2667"/>
        <location filename="../src/editor/dtextedit.cpp" line="2669"/>
        <source>Copy failed: not enough memory</source>
        <translation>内存不足，复制失败</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2762"/>
        <location filename="../src/editor/dtextedit.cpp" line="2764"/>
        <source>Press ALT and click lines to edit in column mode</source>
        <translation>请使用ALT+鼠标点选切换列编辑模式</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="381"/>
        <source>Change Case</source>
        <translation>切换大小写</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="382"/>
        <source>Upper Case</source>
        <translation>大写</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="383"/>
        <source>Lower Case</source>
        <translation>小写</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="384"/>
        <source>Capitalize</source>
        <translation>首字母大写</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="76"/>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1153"/>
        <source>Selected line(s) copied</source>
        <translation>已复制选中行到剪贴板</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1159"/>
        <source>Current line copied</source>
        <translation>已复制当前行到剪贴板</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1184"/>
        <source>Selected line(s) clipped</source>
        <translation>已剪切选中行到剪贴板</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1195"/>
        <source>Current line clipped</source>
        <translation>已剪切当前行到剪贴板</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2681"/>
        <location filename="../src/editor/dtextedit.cpp" line="2683"/>
        <source>Paste failed: not enough memory</source>
        <translation>内存不足，粘贴失败</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="3758"/>
        <source>Read-Only mode is off</source>
        <translation>只读模式已关闭</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="3768"/>
        <location filename="../src/editor/dtextedit.cpp" line="3788"/>
        <location filename="../src/editor/dtextedit.cpp" line="6795"/>
        <location filename="../src/editor/dtextedit.cpp" line="6903"/>
        <location filename="../src/editor/dtextedit.cpp" line="6911"/>
        <location filename="../src/editor/dtextedit.cpp" line="6922"/>
        <source>Read-Only mode is on</source>
        <translation>只读模式已开启</translation>
    </message>
</context>
<context>
    <name>WarningNotices</name>
    <message>
        <location filename="../src/controls/warningnotices.cpp" line="23"/>
        <source>Reload</source>
        <translation>重新载入</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/controls/warningnotices.cpp" line="24"/>
        <location filename="../src/widgets/window.cpp" line="484"/>
        <source>Save as</source>
        <translation>另存为</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="480"/>
        <source>New window</source>
        <translation>新窗口</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="481"/>
        <source>New tab</source>
        <translation>新标签页</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="482"/>
        <source>Open file</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="483"/>
        <location filename="../src/widgets/window.cpp" line="2996"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="485"/>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="486"/>
        <source>Switch theme</source>
        <translation>切换主题</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="487"/>
        <location filename="../src/widgets/window.cpp" line="2099"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="606"/>
        <location filename="../src/widgets/window.cpp" line="3243"/>
        <source>Read-Only</source>
        <translation>只读</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="622"/>
        <source>You do not have permission to open %1</source>
        <translation>您没有权限打开%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="662"/>
        <location filename="../src/widgets/window.cpp" line="2560"/>
        <source>Invalid file: %1</source>
        <translation>无效文件：%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="794"/>
        <location filename="../src/widgets/window.cpp" line="840"/>
        <source>Do you want to save this file?</source>
        <translation>您是否要保存此文件？</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1106"/>
        <source>You do not have permission to save %1</source>
        <translation>您没有权限保存%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1126"/>
        <source>Saved successfully</source>
        <translation>文件已保存</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1162"/>
        <location filename="../src/widgets/window.cpp" line="1261"/>
        <location filename="../src/widgets/window.cpp" line="1302"/>
        <source>Save File</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1263"/>
        <source>Encoding</source>
        <translation>编码</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1508"/>
        <source>Read-Only mode is on</source>
        <translation>只读模式已开启</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1986"/>
        <source>Current location remembered</source>
        <translation>已记住当前位置</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2049"/>
        <source>Ctrl+&apos;=&apos;</source>
        <translation>Ctrl+&apos;=&apos;</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2052"/>
        <source>Ctrl+&apos;-&apos;</source>
        <translation>Ctrl+&apos;-&apos;</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2081"/>
        <source>Editor</source>
        <translation>编辑</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2650"/>
        <source>Untitled %1</source>
        <translation>未命名文档%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2994"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2995"/>
        <source>Discard</source>
        <translation>不保存</translation>
    </message>
</context>
</TS>
